Cleanups

Francois Gouget fgouget at free.fr
Wed Oct 31 22:33:41 CST 2001



Changelog:

 * controls/combo.c,
   dlls/comctl32/comboex.c,
   dlls/comctl32/tab.c,
   dlls/commdlg/filedlgbrowser.c,
   dlls/kernel/toolhelp.c,
   dlls/ntdll/reg.c,
   dlls/oleaut32/variant.c,
   dlls/shell32/changenotify.c,
   dlls/shell32/iconcache.c,
   dlls/shell32/pidl.c,
   dlls/shell32/shellord.c,
   dlls/shell32/shlfolder.c,
   dlls/shell32/shlmenu.c,
   dlls/shell32/shv_item_cmenu.c,
   dlls/shlwapi/reg.c,
   dlls/shlwapi/string.c,
   dlls/user/exticon.c,
   dlls/wsock32/socket.c,
   graphics/win16drv/init.c,
   graphics/win16drv/prtdrv.c,
   loader/module.c,
   msdos/dosmem.c,
   windows/sysparams.c

   Don't prefix %p with 0x
   Various english fixes


--
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
     The software said it requires Win95 or better, so I installed Linux.
-------------- next part --------------
Index: controls/combo.c
===================================================================
RCS file: /home/wine/wine/controls/combo.c,v
retrieving revision 1.78
diff -u -r1.78 combo.c
--- controls/combo.c	2001/09/19 20:37:04	1.78
+++ controls/combo.c	2001/10/31 22:26:15
@@ -141,7 +141,7 @@
 	if( !(GetWindowLongA( hwnd, GWL_EXSTYLE ) & WS_EX_NOPARENTNOTIFY) )
 	      lphc->wState |= CBF_NOTIFY;
 
-        TRACE("[0x%p], style = %08x\n", lphc, lphc->dwStyle );
+        TRACE("[%p], style = %08x\n", lphc, lphc->dwStyle );
         return TRUE;
     }
     return FALSE;
Index: dlls/comctl32/comboex.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/comboex.c,v
retrieving revision 1.36
diff -u -r1.36 comboex.c
--- dlls/comctl32/comboex.c	2001/08/10 22:49:35	1.36
+++ dlls/comctl32/comboex.c	2001/10/31 22:26:18
@@ -51,7 +51,7 @@
  *
  *  mod 4
  *   1. Implemented CBN_SELCHANGE, CBN_KILLFOCUS, and CBN_SELENDOK.
- *   2. Fix putting text in CBEN_ENDEDIT notifys for CBN_DROPDOWN case.
+ *   2. Fix putting text in CBEN_ENDEDIT notifies for CBN_DROPDOWN case.
  *   3. Lock image selected status to focus state of edit control if
  *      edit control exists. Mimics native actions.
  *   4. Implemented WM_SETFOCUS in EditWndProc to track status of 
@@ -531,7 +531,7 @@
 {
     COMBOEX_INFO *infoPtr = COMBOEX_GetInfoPtr (hwnd);
 
-    TRACE("-- 0x%p\n", infoPtr->himl);
+    TRACE("-- %p\n", infoPtr->himl);
 
     return (LRESULT)infoPtr->himl;
 }
Index: dlls/comctl32/tab.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/tab.c,v
retrieving revision 1.61
diff -u -r1.61 tab.c
--- dlls/comctl32/tab.c	2001/09/11 00:32:32	1.61
+++ dlls/comctl32/tab.c	2001/11/01 02:46:38
@@ -1160,9 +1160,8 @@
       INT iIndexStart=0,iIndexEnd=0, iCount=0;
 
       /*
-       * Ok Microsoft trys to even out the rows. place the same
+       * Ok windows tries to even out the rows. place the same
        * number of tabs in each row. So lets give that a shot
-       *
        */
 
       tabPerRow = infoPtr->uNumItem / (infoPtr->uNumRows);
@@ -1218,7 +1217,7 @@
  	       (infoPtr->items[iIndexEnd].rect.top ==
                 infoPtr->items[iIndexStart].rect.top) ;
             iIndexEnd++)
-        /* intentionaly blank */;
+        /* intentionally blank */;
 
         /* 
          * we need to justify these tabs so they fill the whole given
Index: dlls/commdlg/filedlgbrowser.c
===================================================================
RCS file: /home/wine/wine/dlls/commdlg/filedlgbrowser.c,v
retrieving revision 1.28
diff -u -r1.28 filedlgbrowser.c
--- dlls/commdlg/filedlgbrowser.c	2001/07/25 00:43:30	1.28
+++ dlls/commdlg/filedlgbrowser.c	2001/10/31 22:26:23
@@ -778,7 +742,7 @@
       | !(ulAttr & (SFGAO_FILESYSTEM | SFGAO_FILESYSANCESTOR))) /* special folder */
         return S_FALSE;
 
-    /* always include directorys and links */
+    /* always include directories and links */
     if(ulAttr & (SFGAO_FOLDER | SFGAO_LINK)) 
         return S_OK;
 
Index: dlls/kernel/toolhelp.c
===================================================================
RCS file: /home/wine/wine/dlls/kernel/toolhelp.c,v
retrieving revision 1.12
diff -u -r1.12 toolhelp.c
--- dlls/kernel/toolhelp.c	2001/07/25 00:43:30	1.12
+++ dlls/kernel/toolhelp.c	2001/11/01 02:46:40
@@ -21,7 +21,7 @@
 DEFAULT_DEBUG_CHANNEL(toolhelp);
 
 
-/* FIXME: to make this working, we have to callback all these registered 
+/* FIXME: to make this work, we have to call back all these registered 
  * functions from all over the WINE code. Someone with more knowledge than
  * me please do that. -Marcus
  */
Index: dlls/ntdll/reg.c
===================================================================
RCS file: /home/wine/wine/dlls/ntdll/reg.c,v
retrieving revision 1.29
diff -u -r1.29 reg.c
--- dlls/ntdll/reg.c	2001/07/19 00:39:09	1.29
+++ dlls/ntdll/reg.c	2001/11/01 02:53:23
@@ -712,7 +712,7 @@
 /******************************************************************************
  *  RtlOpenCurrentUser		[NTDLL.@]
  *
- * if we return just HKEY_CURRENT_USER the advapi try's to find a remote
+ * if we return just HKEY_CURRENT_USER the advapi tries to find a remote
  * registry (odd handle) and fails
  *
  */
Index: dlls/oleaut32/variant.c
===================================================================
RCS file: /home/wine/wine/dlls/oleaut32/variant.c,v
retrieving revision 1.28
diff -u -r1.28 variant.c
--- dlls/oleaut32/variant.c	2001/10/04 16:14:24	1.28
+++ dlls/oleaut32/variant.c	2001/10/31 22:26:26
@@ -4264,7 +4264,7 @@
 {
     struct tm t;
 
-    TRACE("( 0x%x, 0x%x, 0x%p ), stub\n", wDosDate, wDosTime, pvtime );
+    TRACE("( 0x%x, 0x%x, %p ), stub\n", wDosDate, wDosTime, pvtime );
     
     t.tm_sec = (wDosTime & 0x001f) * 2;
     t.tm_min = (wDosTime & 0x07e0) >> 5;
@@ -4356,7 +4356,7 @@
     wDosTime = 0;
     wDosDate = 0;
 
-    TRACE("( 0x%x, 0x%x, 0x%p ), stub\n", *wDosDate, *wDosTime, &pvtime );
+    TRACE("( 0x%x, 0x%x, %p ), stub\n", *wDosDate, *wDosTime, &pvtime );
 
     if (DateToTm(pvtime, 0, &t) < 0) return 0;
 
Index: dlls/shell32/changenotify.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/changenotify.c,v
retrieving revision 1.13
diff -u -r1.13 changenotify.c
--- dlls/shell32/changenotify.c	2001/10/02 17:25:36	1.13
+++ dlls/shell32/changenotify.c	2001/11/01 02:46:43
@@ -20,10 +20,10 @@
 typedef struct _NOTIFICATIONLIST
 {
 	struct _NOTIFICATIONLIST *next;
-	struct _NOTIFICATIONLIST *prev; 
+	struct _NOTIFICATIONLIST *prev;
 	HWND hwnd;		/* window to notify */
 	DWORD uMsg;		/* message to send */
-	LPNOTIFYREGISTER apidl; /* array of entrys to watch*/
+	LPNOTIFYREGISTER apidl; /* array of entries to watch*/
 	UINT cidl;		/* number of pidls in array */
 	LONG wEventMask;	/* subscribed events */
 	DWORD dwFlags;		/* client flags */
Index: dlls/shell32/iconcache.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/iconcache.c,v
retrieving revision 1.48
diff -u -r1.48 iconcache.c
--- dlls/shell32/iconcache.c	2001/08/16 18:49:57	1.48
+++ dlls/shell32/iconcache.c	2001/11/01 02:46:43
@@ -164,7 +164,7 @@
  * SIC_GetIcon				[internal]
  *
  * NOTES
- *  retrives the specified icon from the iconcache. if not found try's to load the icon
+ *  retrieves the specified icon from the iconcache. if not found tries to load the icon
  */
 static HICON WINE_UNUSED SIC_GetIcon (LPCSTR sSourceFile, INT dwSourceIndex, BOOL bSmallIcon )
 {	INT index;
Index: dlls/shell32/pidl.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/pidl.c,v
retrieving revision 1.61
diff -u -r1.61 pidl.c
--- dlls/shell32/pidl.c	2001/10/14 16:15:05	1.61
+++ dlls/shell32/pidl.c	2001/10/31 22:26:27
@@ -821,7 +821,7 @@
  * SHGetSpecialFolderLocation		[SHELL32.@]
  *
  * gets the folder locations from the registry and creates a pidl
- * creates missing reg keys and directorys
+ * creates missing reg keys and directories
  * 
  * PARAMS
  *   hwndOwner [I]
@@ -1839,7 +1839,7 @@
 /*************************************************************************
 * ILCopyaPidl
 *
-* copys a aPidl struct
+* copies a aPidl struct
 */
 LPITEMIDLIST *  _ILCopyaPidl(LPITEMIDLIST * apidlsrc, UINT cidl)
 {
Index: dlls/shell32/shellord.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shellord.c,v
retrieving revision 1.87
diff -u -r1.87 shellord.c
--- dlls/shell32/shellord.c	2001/10/14 16:15:09	1.87
+++ dlls/shell32/shellord.c	2001/11/01 02:46:45
@@ -27,7 +27,7 @@
 /*************************************************************************
  * ParseFieldA					[internal]
  *
- * copys a field from a ',' delimited string
+ * copies a field from a ',' delimited string
  * 
  * first field is nField = 1
  */
@@ -61,7 +61,7 @@
 /*************************************************************************
  * ParseFieldW			[internal]
  *
- * copys a field from a ',' delimited string
+ * copies a field from a ',' delimited string
  * 
  * first field is nField = 1
  */
@@ -1233,8 +1233,8 @@
  * NOTES
  *  parameter1 is return value from SHAllocShared
  *  parameter2 is return value from GetCurrentProcessId
- *  the receiver of (WM_USER+2) trys to lock the HANDLE (?) 
- *  the returnvalue seems to be a memoryadress
+ *  the receiver of (WM_USER+2) tries to lock the HANDLE (?) 
+ *  the return value seems to be a memory address
  */
 LPVOID WINAPI SHLockShared(HANDLE hmem, DWORD procID)
 {	TRACE("handle=0x%04x procID=0x%04lx\n",hmem,procID);
Index: dlls/shell32/shlfolder.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shlfolder.c,v
retrieving revision 1.60
diff -u -r1.60 shlfolder.c
--- dlls/shell32/shlfolder.c	2001/09/19 22:26:53	1.60
+++ dlls/shell32/shlfolder.c	2001/11/01 02:46:46
@@ -1551,7 +1551,7 @@
 /****************************************************************************
  * ISFHelper_fnCopyItems
  *
- * copys items to this folder
+ * copies items to this folder
  */
 static HRESULT WINAPI ISFHelper_fnCopyItems(
 	ISFHelper *iface,
Index: dlls/shell32/shlmenu.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shlmenu.c,v
retrieving revision 1.23
diff -u -r1.23 shlmenu.c
--- dlls/shell32/shlmenu.c	2001/08/16 18:49:57	1.23
+++ dlls/shell32/shlmenu.c	2001/11/01 02:46:47
@@ -757,7 +757,7 @@
  * FileMenu_GetItemExtent			[SHELL32.144]
  * 
  * NOTES
- *  if the menu is to big, entrys are getting cut away!!
+ *  if the menu is to big, entries are getting cut away!!
  */
 DWORD WINAPI FileMenu_GetItemExtent (HMENU hMenu, UINT uPos)
 {	RECT rect;
Index: dlls/shell32/shv_item_cmenu.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shv_item_cmenu.c,v
retrieving revision 1.6
diff -u -r1.6 shv_item_cmenu.c
--- dlls/shell32/shv_item_cmenu.c	2001/08/16 18:49:57	1.6
+++ dlls/shell32/shv_item_cmenu.c	2001/11/01 02:46:47
@@ -337,7 +337,7 @@
 /**************************************************************************
  * DoCopyOrCut
  *
- * copys the currently selected items into the clipboard
+ * copies the currently selected items into the clipboard
  */
 static BOOL DoCopyOrCut(
 	IContextMenu *iface,
Index: dlls/shlwapi/reg.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/reg.c,v
retrieving revision 1.15
diff -u -r1.15 reg.c
--- dlls/shlwapi/reg.c	2001/10/28 21:13:16	1.15
+++ dlls/shlwapi/reg.c	2001/11/01 02:46:47
@@ -320,7 +320,7 @@
 	if (!pvData || !pcbData) return ERROR_INVALID_FUNCTION; /* FIXME:wrong*/
 	TRACE("key '%s', value '%s', datalen %ld,  %s\n",
 	      debugstr_a(pSubKey), debugstr_a(pValue), *pcbData,
-	      (flagIgnoreHKCU) ? "Ignoring HKCU" : "Trys HKCU then HKLM");
+	      (flagIgnoreHKCU) ? "Ignoring HKCU" : "Tries HKCU then HKLM");
 
 	ret = SHRegOpenUSKeyA(pSubKey, 0x1, 0, &myhuskey, flagIgnoreHKCU);
 	if (ret == ERROR_SUCCESS) {
@@ -354,7 +354,7 @@
 	if (!pvData || !pcbData) return ERROR_INVALID_FUNCTION; /* FIXME:wrong*/
 	TRACE("key '%s', value '%s', datalen %ld,  %s\n",
 	      debugstr_w(pSubKey), debugstr_w(pValue), *pcbData,
-	      (flagIgnoreHKCU) ? "Ignoring HKCU" : "Trys HKCU then HKLM");
+	      (flagIgnoreHKCU) ? "Ignoring HKCU" : "Tries HKCU then HKLM");
 
 	ret = SHRegOpenUSKeyW(pSubKey, 0x1, 0, &myhuskey, flagIgnoreHKCU);
 	if (ret == ERROR_SUCCESS) {
@@ -382,7 +382,7 @@
 
 	TRACE("key '%s', value '%s', %s\n",
 	      debugstr_a(pszSubKey), debugstr_a(pszValue),
-	      (fIgnoreHKCU) ? "Ignoring HKCU" : "Trys HKCU then HKLM");
+	      (fIgnoreHKCU) ? "Ignoring HKCU" : "Tries HKCU then HKLM");
 
 	datalen = sizeof(data)-1;
 	if (!(retvalue = SHRegGetUSValueA( pszSubKey, pszValue, &type, 
@@ -437,7 +437,7 @@
 
 	TRACE("key '%s', value '%s', %s\n",
 	      debugstr_w(pszSubKey), debugstr_w(pszValue),
-	      (fIgnoreHKCU) ? "Ignoring HKCU" : "Trys HKCU then HKLM");
+	      (fIgnoreHKCU) ? "Ignoring HKCU" : "Tries HKCU then HKLM");
 
 	datalen = (sizeof(data)-1) * sizeof(WCHAR);
 	if (!(retvalue = SHRegGetUSValueW( pszSubKey, pszValue, &type, 
Index: dlls/shlwapi/string.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/string.c,v
retrieving revision 1.12
diff -u -r1.12 string.c
--- dlls/shlwapi/string.c	2001/06/20 23:03:16	1.12
+++ dlls/shlwapi/string.c	2001/10/31 22:26:28
@@ -380,7 +380,7 @@
  */
 HRESULT WINAPI StrRetToBufA (LPSTRRET src, const ITEMIDLIST *pidl, LPSTR dest, DWORD len)
 {
-	TRACE("dest=0x%p len=0x%lx strret=0x%p pidl=%p stub\n",dest,len,src,pidl);
+	TRACE("dest=%p len=0x%lx strret=%p pidl=%p stub\n",dest,len,src,pidl);
 
 	switch (src->uType)
 	{
@@ -418,7 +418,7 @@
  */
 HRESULT WINAPI StrRetToBufW (LPSTRRET src, const ITEMIDLIST *pidl, LPWSTR dest, DWORD len)
 {
-	TRACE("dest=0x%p len=0x%lx strret=0x%p pidl=%p stub\n",dest,len,src,pidl);
+	TRACE("dest=%p len=0x%lx strret=%p pidl=%p stub\n",dest,len,src,pidl);
 
 	switch (src->uType)
 	{
Index: dlls/user/exticon.c
===================================================================
RCS file: /home/wine/wine/dlls/user/exticon.c,v
retrieving revision 1.14
diff -u -r1.14 exticon.c
--- dlls/user/exticon.c	2001/10/14 16:18:53	1.14
+++ dlls/user/exticon.c	2001/11/01 02:46:48
@@ -203,7 +203,7 @@
 	  lpID->idType = lpcid->idType;
 	  lpID->idCount = lpcid->idCount;
 
-	  /* copy the entrys */
+	  /* copy the entries */
 	  for( i=0; i < lpcid->idCount; i++ )
 	  {
 	    memcpy((void*)&(lpID->idEntries[i]),(void*)&(lpcid->idEntries[i]), sizeof(CURSORICONDIRENTRY) - 2);
Index: graphics/win16drv/init.c
===================================================================
RCS file: /home/wine/wine/graphics/win16drv/init.c,v
retrieving revision 1.38
diff -u -r1.38 init.c
--- graphics/win16drv/init.c	2001/08/15 23:30:15	1.38
+++ graphics/win16drv/init.c	2001/10/31 22:26:32
@@ -224,7 +224,7 @@
     PDEVICE_HEADER *pPDH;
     WIN16DRV_PDEVICE *physDev;
 
-    TRACE("In creatdc for (%s,%s,%s) initData 0x%p\n",
+    TRACE("In creatdc for (%s,%s,%s) initData %p\n",
 	  driver, device, output, initData);
 
     physDev = (WIN16DRV_PDEVICE *)HeapAlloc( GetProcessHeap(), 0, sizeof(*physDev) );
@@ -238,7 +238,7 @@
         HeapFree( GetProcessHeap(), 0, physDev );
         return FALSE;
     }
-    TRACE("windevCreateDC pLPD 0x%p\n", pLPD);
+    TRACE("windevCreateDC pLPD %p\n", pLPD);
 
     /* Now Get the device capabilities from the printer driver */
     memset( &physDev->DevCaps, 0, sizeof(physDev->DevCaps) );
Index: graphics/win16drv/prtdrv.c
===================================================================
RCS file: /home/wine/wine/graphics/win16drv/prtdrv.c,v
retrieving revision 1.21
diff -u -r1.21 prtdrv.c
--- graphics/win16drv/prtdrv.c	2001/07/24 21:45:23	1.21
+++ graphics/win16drv/prtdrv.c	2001/10/31 22:26:33
@@ -82,14 +82,12 @@
       LoadPrinterDrvFunc(ADVANCEDSETUPDIALOG);
       LoadPrinterDrvFunc(DIALOGFN);
       LoadPrinterDrvFunc(PSEUDOEDIT);
-      TRACE("got func CONTROL 0x%p enable 0x%p enumDfonts 0x%p realizeobject 0x%p extextout 0x%p\n",
+      TRACE("got func CONTROL %p enable %p enumDfonts %p realizeobject %p extextout %p\n",
               pLPD->fn[FUNC_CONTROL],
               pLPD->fn[FUNC_ENABLE],
               pLPD->fn[FUNC_ENUMDFONTS],
               pLPD->fn[FUNC_REALIZEOBJECT],
               pLPD->fn[FUNC_EXTTEXTOUT]);
-      
-
 }
 
 
Index: loader/module.c
===================================================================
RCS file: /home/wine/wine/loader/module.c,v
retrieving revision 1.140
diff -u -r1.140 module.c
--- loader/module.c	2001/10/14 16:15:09	1.140
+++ loader/module.c	2001/10/31 22:26:40
@@ -1456,7 +1456,7 @@
                     pwm->flags &= ~WINE_MODREF_DONT_RESOLVE_REFS;
                     PE_fixup_imports( pwm );
 		}
-		TRACE("Already loaded module '%s' at 0x%08x, count=%d, \n", filename, pwm->module, pwm->refCount);
+		TRACE("Already loaded module '%s' at 0x%08x, count=%d\n", filename, pwm->module, pwm->refCount);
                 if (allocated_libdir)
                 {
                     HeapFree ( GetProcessHeap(), 0, (LPSTR)libdir );
@@ -1502,7 +1502,7 @@
 		if(pwm)
 		{
 			/* Initialize DLL just loaded */
-			TRACE("Loaded module '%s' at 0x%08x, \n", filename, pwm->module);
+			TRACE("Loaded module '%s' at 0x%08x\n", filename, pwm->module);
                         if (!TRACE_ON(module))
                             TRACE_(loaddll)("Loaded module '%s' : %s\n", filename, filetype);
 			/* Set the refCount here so that an attach failure will */
@@ -1531,7 +1531,7 @@
             libdir = NULL;
         }
         RtlReleasePebLock();
-	WARN("Failed to load module '%s'; error=0x%08lx, \n", filename, GetLastError());
+	WARN("Failed to load module '%s'; error=0x%08lx\n", filename, GetLastError());
 	HeapFree ( GetProcessHeap(), 0, filename );
 	return NULL;
 }
Index: msdos/dosmem.c
===================================================================
RCS file: /home/wine/wine/msdos/dosmem.c,v
retrieving revision 1.32
diff -u -r1.32 dosmem.c
--- msdos/dosmem.c	2001/10/14 16:25:48	1.32
+++ msdos/dosmem.c	2001/10/31 22:26:41
@@ -820,7 +820,7 @@
    LPVOID       lin;
 
    lin=DOSMEM_dosmem+(x&0xffff)+(((x&0xffff0000)>>16)*16);
-   TRACE_(selector)("(0x%08lx) returns 0x%p.\n", x, lin );
+   TRACE_(selector)("(0x%08lx) returns %p.\n", x, lin );
    return lin;
 }
 
Index: windows/sysparams.c
===================================================================
RCS file: /home/wine/wine/windows/sysparams.c,v
retrieving revision 1.23
diff -u -r1.23 sysparams.c
--- windows/sysparams.c	2001/10/17 17:50:05	1.23
+++ windows/sysparams.c	2001/11/01 02:47:04
@@ -326,7 +326,7 @@
 	    lpnm->iSmCaptionHeight = lpnm->iSmCaptionWidth;
 	    SystemParametersInfoA( SPI_GETICONTITLELOGFONT, 0, (LPVOID)&(lpnm->lfSmCaptionFont), 0 );
 
-	    /* menus, FIXME: names of wine.conf entrys are bogus */
+	    /* menus, FIXME: names of wine.conf entries are bogus */
 
 	    lpnm->iMenuWidth = GetProfileIntA( "Desktop", "MenuWidth", 13 );	/* size of the menu buttons*/
 	    lpnm->iMenuHeight = GetProfileIntA( "Desktop", "MenuHeight", 


More information about the wine-patches mailing list
Index: dlls/wsock32/socket.c
===================================================================
RCS file: /home/wine/wine/dlls/wsock32/socket.c,v
retrieving revision 1.14
diff -u -r1.14 socket.c
--- dlls/wsock32/socket.c	2001/09/14 01:00:20	1.14
+++ dlls/wsock32/socket.c	2001/11/01 02:46:51
@@ -479,7 +479,7 @@
 		foundRoutes = WSCNTL_GetRouteTable(numRoutes, routeTable);
 		if (foundRoutes < 0)
 		{
-		    ERR ("Unable to open /proc filesystem to parse the route entrys!\n");
+		    ERR ("Unable to open /proc filesystem to parse the route entries!\n");
 		    free(routeTable);
 		    return -1;
 		}
@@ -888,7 +888,7 @@
     /* skip the header line */
     fgets(buf, sizeof(buf), file);
 
     /* parse the rest of the file and put the matching entrys into routeTable.
        Format of procfs route entry:
        Iface Destination Gateway Flags RefCnt Use Metric Mask  MTU Window IRTT
        lo 0000007F 00000000 0001 0 0 0 000000FF 0 0 0
@@ -888,7 +888,7 @@
     fgets(buf, sizeof(buf), file);
 
-    /* parse the rest of the file and put the matching entrys into routeTable.
+    /* parse the rest of the file and put the matching entries into routeTable.
        Format of procfs route entry:
        Iface Destination Gateway Flags RefCnt Use Metric Mask  MTU Window IRTT